##########################
The Python Benchmark Suite
##########################

.. image:: https://img.shields.io/pypi/v/pyperformance.svg
   :alt: Latest pyperformance release on the Python Cheeseshop (PyPI)
   :target: https://pypi.python.org/pypi/pyperformance

.. image:: https://github.com/python/pyperformance/actions/workflows/main.yml/badge.svg
   :alt: Build status of pyperformance on GitHub Actions
   :target: https://github.com/python/pyperformance/actions

The ``pyperformance`` project is intended to be an authoritative source of
benchmarks for all Python implementations. The focus is on real-world
benchmarks, rather than synthetic benchmarks, using whole applications when
possible.

* `pyperformance documentation <http://pyperformance.readthedocs.io/>`_
* `pyperformance GitHub project <https://github.com/python/pyperformance>`_
  (source code, issues)
* `Download pyperformance on PyPI <https://pypi.python.org/pypi/pyperformance>`_

pyperformance is not tuned for PyPy yet: use the `PyPy benchmarks project
<https://foss.heptapod.net/pypy/benchmarks>`_ instead to measure PyPy
performances.

pyperformance is distributed under the MIT license.
